@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
 from OFS.ObjectManager import BeforeDeleteException
 from zope.interface import Interface
-from zope.interface import implements
+from zope.interface import implementer
 
 
 class ILinkIntegrityNotificationException(Interface):
     """ an exception indicating a prevented link integrity breach """
 
 
+@implementer(ILinkIntegrityNotificationException)
 class LinkIntegrityNotificationException(BeforeDeleteException):
     """ an exception indicating a prevented link integrity breach """
-    implements(ILinkIntegrityNotificationException)
 
     def __str__(self):
         args = self.args
